@@ -38,7 +38,7 @@ from warnings import warn_explicit
 from praw import decorators, errors, helpers
 from praw.settings import CONFIG
 
-__version__ = '2.0.8'
+__version__ = '2.0.10'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -66,6 +66,7 @@ class Config(object):  # pylint: disable-msg=R0903
                  'contributors':        'r/%s/about/contributors/',
                  'controversial':       'controversial/',
                  'del':                 'api/del/',
+                 'deleteflair':         'api/deleteflair',
                  'delete_sr_header':    'r/%s/api/delete_sr_header',
                  'delete_sr_image':     'r/%s/api/delete_sr_img',
                  'distinguish':         'api/distinguish/',
@@ -77,6 +78,7 @@ class Config(object):  # pylint: disable-msg=R0903
                  'flairlist':           'r/%s/api/flairlist/',
                  'flairtemplate':       'api/flairtemplate/',
                  'friend':              'api/friend/',
+                 'friends':             'prefs/friends/',
                  'help':                'help/',
                  'hide':                'api/hide/',
                  'inbox':               'message/inbox/',
@@ -530,6 +532,7 @@ class UnauthenticatedReddit(BaseReddit):
         """
         return self.get_comments('all', gilded_only, *args, **kwargs)
 
+    @decorators.restrict_access(scope='read')
     def get_comments(self, subreddit, gilded_only=False, *args, **kwargs):
         """Return latest comments on the given subreddit.
 
@@ -542,6 +545,7 @@ class UnauthenticatedReddit(BaseReddit):
             url = self.config['subreddit_comments'] % six.text_type(subreddit)
         return self.get_content(url, *args, **kwargs)
 
+    @decorators.restrict_access(scope='read')
     def get_controversial(self, *args, **kwargs):
         """Return controversial page."""
         return self.get_content(self.config['controversial'], *args, **kwargs)
@@ -553,6 +557,7 @@ class UnauthenticatedReddit(BaseReddit):
                                  six.text_type(subreddit), params=params)
         return data['users'][0]
 
+    @decorators.restrict_access(scope='read')
     def get_front_page(self, *args, **kwargs):
         """Return the front page submissions.
 
@@ -599,6 +604,7 @@ class UnauthenticatedReddit(BaseReddit):
         return self.request_json(self.config['moderators'] %
                                  six.text_type(subreddit))
 
+    @decorators.restrict_access(scope='read')
     def get_new(self, *args, **kwargs):
         """Return new page."""
         return self.get_content(self.config['new'], *args, **kwargs)
@@ -618,7 +624,6 @@ class UnauthenticatedReddit(BaseReddit):
         """Return a Redditor instance for the user_name specified."""
         return objects.Redditor(self, user_name, *args, **kwargs)
 
-    @decorators.restrict_access(scope='read')
     def get_submission(self, url=None, submission_id=None, comment_limit=0,
                        comment_sort=None):
         """Return a Submission object for the given url or submission_id.
@@ -644,6 +649,7 @@ class UnauthenticatedReddit(BaseReddit):
             return self.get_random_subreddit()
         return objects.Subreddit(self, subreddit_name, *args, **kwargs)
 
+    @decorators.restrict_access(scope='read')
     def get_top(self, *args, **kwargs):
         """Return top page."""
         return self.get_content(self.config['top'], *args, **kwargs)
@@ -832,8 +838,6 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
         self.request_json(self.config['login'], data=data)
         # Update authentication settings
         self._authentication = True
-        self.access_token = None
-        self.refresh_token = None
         self.user = self.get_redditor(user)
         self.user.__class__ = objects.LoggedInRedditor
 
@@ -880,12 +884,8 @@ class AuthenticatedReddit(OAuth2Reddit, UnauthenticatedReddit):
         self.access_token = access_token
         self.refresh_token = refresh_token
         # Update the user object
-        if not update_user:
-            pass
-        elif 'identity' in scope:
+        if update_user and 'identity' in scope:
             self.user = self.get_me()
-        else:
-            self.user = None
 
 
 class ModConfigMixin(AuthenticatedReddit):
@@ -1130,6 +1130,17 @@ class ModFlairMixin(AuthenticatedReddit):
                 'link_flair_self_assign_enabled': link_flair_self_assign}
         return self.request_json(self.config['flairconfig'], data=data)
 
+    @decorators.restrict_access(scope='modflair')
+    def delete_flair(self, subreddit, user):
+        """Delete the flair for the given user on the given subreddit.
+
+        :returns: The json response from the server.
+
+        """
+        data = {'r': six.text_type(subreddit),
+                'name': six.text_type(user)}
+        return self.request_json(self.config['deleteflair'], data=data)
+
     @decorators.restrict_access(scope='modflair')
     def get_flair_list(self, subreddit, limit=0):
         """Return a get_content generator of flair mappings.
@@ -1325,14 +1336,19 @@ class PrivateMessagesMixin(AuthenticatedReddit):
         return self.get_content(self.config['sent'], limit=limit)
 
     @decorators.restrict_access(scope='privatemessages')
-    def get_unread(self, limit=0, unset_has_mail=False):
+    def get_unread(self, limit=0, unset_has_mail=False, update_user=False):
         """Return a generator for unread messages.
 
         :param unset_has_mail: When true, clear the has_mail flag (orangered)
             for the user.
+        :param update_user: If both unset_has_mail and update user is true, set
+            the has_mail attribute of the logged-in user to False.
 
         """
         params = {'mark': 'true'} if unset_has_mail else None
+        # Update the user object
+        if unset_has_mail and update_user and hasattr(self.user, 'has_mail'):
+            self.user.has_mail = False
         return self.get_content(self.config['unread'], limit=limit,
                                 params=params)
 
