@@ -478,8 +478,9 @@ class Comment(Editable, Inboxable, Moderatable, Reportable, Voteable):
         # pylint: disable-msg=W0212
         submission._comments_by_id[self.name] = self
         self._submission = submission
-        for reply in self._replies:
-            reply._update_submission(submission)
+        if self._replies:
+            for reply in self._replies:
+                reply._update_submission(submission)
 
     @property
     def is_root(self):
@@ -617,6 +618,7 @@ class Redditor(Messageable, Refreshable):
         :returns: The json response from the server.
 
         """
+        _request.evict([self.reddit_session.config['friends']])
         return _modify_relationship('friend')(self.reddit_session.user, self)
 
     def mark_as_read(self, messages, unread=False):
@@ -645,6 +647,7 @@ class Redditor(Messageable, Refreshable):
         :returns: The json response from the server.
 
         """
+        _request.evict([self.reddit_session.config['friends']])
         return _modify_relationship('friend', unlink=True)(
             self.reddit_session.user, self)
 
@@ -658,6 +661,11 @@ class LoggedInRedditor(Redditor):
     get_liked = _get_section('liked')
     get_saved = _get_section('saved')
 
+    def get_blocked(self):
+        """Return a UserList of Redditors with whom the user has blocked."""
+        url = self.reddit_session.config['friends']
+        return self.reddit_session.request_json(url)[1]
+
     def get_cached_moderated_reddits(self):
         """Return a cached dictionary of the user's moderated reddits.
 
@@ -671,6 +679,11 @@ class LoggedInRedditor(Redditor):
                 self._mod_subs[six.text_type(sub).lower()] = sub
         return self._mod_subs
 
+    def get_friends(self):
+        """Return a UserList of Redditors with whom the user has friended."""
+        url = self.reddit_session.config['friends']
+        return self.reddit_session.request_json(url)[0]
+
 
 class ModAction(RedditContentObject):
 
@@ -714,6 +727,7 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         return Submission(reddit_session, pseudo_data)
 
     @staticmethod
+    @restrict_access(scope='read')
     def from_url(reddit_session, url, comment_limit=0, comment_sort=None,
                  comments_only=False):
         """Request the url and return a Submission object.
@@ -896,6 +910,7 @@ class Subreddit(Messageable, Refreshable):
                 ('add_flair_template', MFMix.add_flair_template),
                 ('clear_flair_templates', MFMix.clear_flair_templates),
                 ('configure_flair', MFMix.configure_flair),
+                ('delete_flair', MFMix.delete_flair),
                 ('delete_image', MCMix.delete_image),
                 ('get_banned', MOMix.get_banned),
                 ('get_comments', UR.get_comments),
@@ -1029,6 +1044,9 @@ class UserList(RedditContentObject):
     def __len__(self):
         return len(self.children)
 
+    def __unicode__(self):
+        return six.text_type(self.children)
+
 
 def _add_aliases():
     import inspect
