@@ -417,6 +417,14 @@ class MoreCommentsTest(unittest.TestCase, AuthenticatedHelper):
         self.assertTrue(cf_len < acf_len)
         self.assertTrue(saved)
 
+    def test_comments_method(self):
+        for item in self.submission.comments:
+            if isinstance(item, MoreComments):
+                self.assertTrue(item.comments())
+                break
+        else:
+            self.fail('Could not find MoreComment object.')
+
 
 class CommentEditTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
@@ -565,6 +573,11 @@ class FlairTest(unittest.TestCase, AuthenticatedHelper):
         self.assertEqual(flair['flair_text'], None)
         self.assertEqual(flair['flair_css_class'], None)
 
+    def test_delete_flair(self):
+        flair = list(self.subreddit.get_flair_list(limit=1))[0]
+        self.subreddit.delete_flair(flair['user'])
+        self.assertTrue(flair not in self.subreddit.get_flair_list())
+
     def test_flair_csv_and_flair_list(self):
         # Clear all flair
         self.subreddit.clear_all_flair()
@@ -765,6 +778,13 @@ class MessageTest(unittest.TestCase, AuthenticatedHelper):
     def setUp(self):
         self.configure()
 
+    def test_get_unread_update_has_mail(self):
+        self.r.send_message(self.other_user_name, 'Update has mail', 'body')
+        self.r.login(self.other_user_name, '1111')
+        self.assertTrue(self.r.user.has_mail)
+        self.r.get_unread(limit=1, unset_has_mail=True, update_user=True)
+        self.assertFalse(self.r.user.has_mail)
+
     def test_mark_as_read(self):
         oth = Reddit(USER_AGENT, disable_update_check=True)
         oth.login('PyAPITestUser3', '1111')
@@ -1053,6 +1073,39 @@ class OAuth2Test(unittest.TestCase, BasicHelper):
         method2 = self.r.get_submission(submission_id=self.priv_submission_id)
         self.assertEqual(method1, method2)
 
+    @reddit_only
+    def test_scope_read_get_front_page(self):
+        self.r.refresh_access_information(self.refresh_token['mysubreddits'])
+        subscribed = list(self.r.get_my_reddits(limit=None))
+        self.r.refresh_access_information(self.refresh_token['read'])
+        for post in self.r.get_front_page():
+            self.assertTrue(post.subreddit in subscribed)
+
+    @reddit_only
+    def test_scope_read_get_sub_listingr(self):
+        self.r.refresh_access_information(self.refresh_token['read'])
+        subreddit = self.r.get_subreddit(self.priv_sr)
+        self.assertTrue(len(list(subreddit.get_top())))
+
+    @reddit_only
+    def test_scope_read_get_submission_by_url(self):
+        url = ("http://www.reddit.com/r/reddit_api_test_priv/comments/16kbb7/"
+               "google/")
+        self.r.refresh_access_information(self.refresh_token['read'])
+        submission = Submission.from_url(self.r, url)
+        self.assertTrue(submission.num_comments != 0)
+
+    @reddit_only
+    def test_scope_read_priv_sr_comments(self):
+        self.r.refresh_access_information(self.refresh_token['read'])
+        self.assertTrue(len(list(self.r.get_comments(self.priv_sr))))
+
+    @reddit_only
+    def test_scope_read_priv_sub_comments(self):
+        self.r.refresh_access_information(self.refresh_token['read'])
+        submission = Submission.from_id(self.r, self.priv_submission_id)
+        self.assertTrue(len(list(submission.comments)))
+
     @reddit_only
     def test_scope_submit(self):
         self.r.refresh_access_information(self.refresh_token['submit'])
@@ -1098,12 +1151,25 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
         self.configure()
         self.other_user = self.r.get_redditor(self.other_user_name)
 
+    def test_add_remove_friends(self):
+        def verify_add():
+            self.other_user.friend()
+            self.assertTrue(self.other_user in self.r.user.get_friends())
+
+        def verify_remove():
+            self.other_user.unfriend()
+            self.assertTrue(self.other_user not in self.r.user.get_friends())
+
+        if self.other_user in self.r.user.get_friends():
+            verify_remove()
+            verify_add()
+        else:
+            verify_add()
+            verify_remove()
+
     def test_duplicate_login(self):
         self.r.login(self.other_user_name, '1111')
 
-    def test_friend(self):
-        self.other_user.friend()
-
     def test_get_disliked(self):
         # Pulls from get_liked. Problem here may come from get_liked
         item = six_next(self.r.user.get_liked())
@@ -1130,9 +1196,6 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
     def test_get_redditor(self):
         self.assertEqual(self.other_user_id, self.other_user.id)
 
-    def test_unfriend(self):
-        self.other_user.unfriend()
-
     def test_user_set_on_login(self):
         self.assertTrue(isinstance(self.r.user, LoggedInRedditor))
 
